"""Solyanka – lightweight helpers for statement generation tooling."""

from .transaction_patterns.service import EEA_COUNTRIES, Pattern, PatternsService

__all__ = ["EEA_COUNTRIES", "Pattern", "PatternsService"]
__version__ = "0.1.0"
